@@ -1,28 +1,29 @@
 /**
+ *	This file is part of devilspie2
+ *	Copyright (C) 2005 Ross Burton, 2011-2012 Andreas Rönnquist
  *
- *	This file is part of devilspie2.
- *	Copyright 2005 Ross Burton, 2011 Andreas Rönnquist
- *
- *	devilspie2 is free software: you can redistribute it and/or modify
- *	it under the terms of the GNU Lesser General Public License as published by
- *	the Free Software Foundation, either version 3 of the License, or
+ *	devilspie2 is free software: you can redistribute it and/or 
+ *	modify it under the terms of the GNU General Public License as published 
+ *	by the Free Software Foundation, either version 3 of the License, or
  *	(at your option) any later version.
- *
+ * 
  *	devilspie2 is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU Lesser General Public License for more details.
- *
- *	You should have received a copy of the GNU Lesser General Public License
- *	along with devilspie2.  If not, see <http://www.gnu.org/licenses/>.
- *
+ *	GNU General Public License for more details.
+ * 
+ *	You should have received a copy of the GNU General Public License
+ *	along with devilspie2.  
+ *	If not, see <http://www.gnu.org/licenses/>.
  */
+
 #include <string.h>
 
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <gdk/gdk.h>
+#include <glib/gi18n.h>
 
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
@@ -30,10 +31,14 @@
 #include <lua.h>
 #include <lualib.h>
 
+#include <locale.h>
+
 #include "script.h"
 #include "script_functions.h"
 
-#include "version.h"
+#if (GTK_MAJOR_VERSION >= 3)
+#define HAVE_GTK3
+#endif
 
 /**
  *
@@ -42,7 +47,13 @@ GMainLoop *loop=NULL;
 
 static gboolean debug=FALSE;
 static gboolean emulate=FALSE;
-static gboolean version=FALSE;
+static gboolean show_version=FALSE;
+
+#ifdef HAVE_GTK3
+	// libwnck Version Information is only availible if you have 
+	// libwnck 3.0 or later
+	static gboolean show_wnck_version=FALSE;
+#endif
 
 static gchar *script_folder=NULL;
 static gchar *temp_folder=NULL;
@@ -116,7 +127,11 @@ void devilspie_exit()
  */
 static void signal_handler(int sig)
 {
-	printf("\nReceived signal %d (%s)\n", sig, strsignal(sig));
+	printf("\n");
+	printf(_("Received signal:"));
+	printf(" %d (%s)\n", sig, strsignal(sig));
+	
+	done_script_error_messages();
 
 	if (sig==SIGINT)
 		exit(1);
@@ -125,78 +140,20 @@ static void signal_handler(int sig)
 
 
 /**
- * Program main entry
+ *
  */
-int main(int argc, char *argv[])
+void load_scripts()
 {
-	static const GOptionEntry options[]={
-		{ "debug",		'd',	0,	G_OPTION_ARG_NONE,		&debug,			
-			"Print debug info to stdout"},
-		{ "emulate",	'e',	0,	G_OPTION_ARG_NONE,		&emulate,		
-			"Don't apply any rules, only emulate an execution"},
-		{ "folder",		'f',	0,	G_OPTION_ARG_STRING,		&script_folder, 
-			"Folder where scripts are found"},
-		{ "version",	'v',	0,	G_OPTION_ARG_NONE,		&version,
-			"Show Devilspie2 version and quit"},
-		{ NULL }
-	};
-	
-	GError *error=NULL;
-	GOptionContext *context;
-	
 	GDir *dir;
 	const gchar *current_file;
-
-	gdk_init(&argc, &argv);
-
-	context=g_option_context_new("- apply rules on windows");
-	g_option_context_add_main_entries(context,options,NULL);
-	if (!g_option_context_parse(context, &argc, &argv, &error)) {
-		g_print("option parsing failed: %s\n",error->message);
-		exit(EXIT_FAILURE);
-	}
-
-	// if the folder is NULL, default to ~/.config/devilspie2/
-	if (script_folder==NULL) {
-		
-		temp_folder=g_build_path(G_DIR_SEPARATOR_S,g_get_user_config_dir(),"devilspie2",NULL);
-		
-		// check if the folder does exist
-		if (!g_file_test(temp_folder,G_FILE_TEST_IS_DIR)) {
-
-			// - and if it doesn't, create it.
-			if (g_mkdir(temp_folder,0700)!=0) {
-				g_error("Couldn't create the default devilspie folder.");
-			}
-		}
-		
-		script_folder=temp_folder;
-	}
-	
-	if (version) {
-		printf("Devilspie2 v%s\n\n",VERSION_STRING);
-		exit(EXIT_SUCCESS);
-	}
-	
-	if (debug) {
-		printf("Running Devilspie2 in debug mode");
-		
-		if (emulate) printf(" and Emulate mode");
-		
-		printf(".\n\n");
-		
-		printf("Using scripts from folder: %s\n",script_folder);
-		
-		devilspie2_debug=TRUE;
-	}
-	
-	// Should we only run an emulation (don't modify any windows)
-	if (emulate) devilspie2_emulate=emulate;
 	
 	// add all the files in the script_folder to the file_list
 	dir=g_dir_open(script_folder,0,NULL);
 	if (!g_file_test(script_folder,G_FILE_TEST_IS_DIR)) {
-		g_error("script_folder isn't a folder.\n");
+
+		printf(_("script_folder isn't a folder."));
+		printf("\n");
+		
 		devilspie_exit();
 		exit(EXIT_FAILURE);
 	}
@@ -222,25 +179,143 @@ int main(int argc, char *argv[])
 	g_dir_close(dir);
 	
 	if (number_of_files==0) {
-		printf("No script files found in the script folder - exiting.\n\n");
+		printf(_("No script files found in the script folder - exiting."));
+		printf("\n\n");
 		exit(EXIT_SUCCESS);
 	}
 	
 	// print the list of files:
 	
-	if (debug) printf("List of LUA files in folder:\n");
+	if (debug) {
+		printf(_("List of LUA files in folder:"));
+		printf("\n");
 		
-	if (file_list!=NULL) {
+		if (file_list!=NULL) {
 		
-		while(temp_list) {
+			while(temp_list) {
 
-			// is it a LUA file?
-			if (g_str_has_suffix((gchar*)(temp_list->data),".lua")) {
-				if (debug) printf("%s\n",(gchar*)temp_list->data);
+				// is it a LUA file?
+				if (g_str_has_suffix((gchar*)(temp_list->data),".lua")) {
+					printf("%s\n",(gchar*)temp_list->data);
+				}
+				temp_list=temp_list->next;
 			}
-			temp_list=temp_list->next;
 		}
 	}
+}
+
+
+/**
+ * Program main entry
+ */
+int main(int argc, char *argv[])
+{
+	static const GOptionEntry options[]={
+		{ "debug",			'd',	0,	G_OPTION_ARG_NONE,		&debug,			
+			N_("Print debug info to stdout")},
+		{ "emulate",		'e',	0,	G_OPTION_ARG_NONE,		&emulate,		
+			N_("Don't apply any rules, only emulate execution")},
+		{ "folder",			'f',	0,	G_OPTION_ARG_STRING,		&script_folder, 
+			N_("Search for scripts in this folder"),N_("FOLDER")},
+		{ "version",		'v',	0,	G_OPTION_ARG_NONE,		&show_version,
+			N_("Show Devilspie2 version and quit")},
+#ifdef HAVE_GTK3
+		// libwnck Version Information is only availible if you have 
+		// libwnck 3.0 or later
+		{ "wnck-version",	'w',	0,	G_OPTION_ARG_NONE,		&show_wnck_version,
+			N_("Show libwnck version and quit")},
+#endif
+		{ NULL }
+	};
+	
+	GError *error=NULL;
+	GOptionContext *context;
+	
+	// Init gettext stuff
+	setlocale(LC_ALL,"");
+	
+	bindtextdomain(PACKAGE,LOCALEDIR);
+	bind_textdomain_codeset(PACKAGE,"");
+	textdomain(PACKAGE);
+	
+	gdk_init(&argc, &argv);
+	
+	gchar *devilspie2_description=NULL;
+	
+	devilspie2_description=g_strdup_printf(_("apply rules on windows"));
+	
+	gchar *full_desc_string=g_strdup_printf("- %s",devilspie2_description);
+
+	context=g_option_context_new(full_desc_string);
+	g_option_context_add_main_entries(context,options,NULL);
+	if (!g_option_context_parse(context, &argc, &argv, &error)) {
+		g_print(_("option parsing failed: %s"),error->message);
+		printf("\n");
+		exit(EXIT_FAILURE);
+	}
+	
+	g_free(full_desc_string);
+	g_free(devilspie2_description);
+
+	// if the folder is NULL, default to ~/.config/devilspie2/
+	if (script_folder==NULL) {
+		
+		temp_folder=g_build_path(G_DIR_SEPARATOR_S,g_get_user_config_dir(),"devilspie2",NULL);
+		
+		// check if the folder does exist
+		if (!g_file_test(temp_folder,G_FILE_TEST_IS_DIR)) {
+
+			// - and if it doesn't, create it.
+			if (g_mkdir(temp_folder,0700)!=0) {
+				printf(_("Couldn't create the default folder for devilspie2 scripts."));
+				printf("\n");
+				exit(EXIT_FAILURE);
+			}
+		}
+		
+		script_folder=temp_folder;
+	}
+	
+	if (show_version) {
+		printf("Devilspie2 v%s\n\n",DEVILSPIE2_VERSION);
+		exit(EXIT_SUCCESS);
+	}
+#ifdef HAVE_GTK3
+	// libwnck Version Information is only availible if you have 
+	// libwnck 3.0 or later
+	if (show_wnck_version) {
+		printf("libwnck v%d.%d.%d\n\n",WNCK_MAJOR_VERSION,WNCK_MINOR_VERSION,WNCK_MICRO_VERSION);
+		exit(EXIT_SUCCESS);
+	}
+#endif
+	
+	if (debug) {
+		
+		if (emulate) {
+			printf(_("Running devilspie2 in debug and emulate mode."));
+		} else {
+			printf(_("Running devilspie2 in debug mode."));
+		}
+		
+		printf("\n\n");
+		
+		printf(_("Using scripts from folder: %s"),script_folder);
+		
+		printf("\n");
+		
+		devilspie2_debug=TRUE;
+	}
+	
+	// Should we only run an emulation (don't modify any windows)
+	if (emulate) devilspie2_emulate=emulate;
+	
+	if (init_script_error_messages()!=0) {
+		printf(_("Couldn't init script error messages!"));
+		printf("\n");
+		exit(EXIT_FAILURE);
+	}
+	
+	load_scripts();
 	
 	if (debug) printf("------------\n");
 	
@@ -253,8 +328,7 @@ int main(int argc, char *argv[])
 	signal_action.sa_flags = 0;
 	signal_action.sa_handler = signal_handler;
 
-	if (sigaction(SIGINT, &signal_action, NULL) == -1)
-	{
+	if (sigaction(SIGINT, &signal_action, NULL) == -1) {
 		exit(EXIT_FAILURE);
 	}
 
